@@ -29,7 +29,7 @@ class OptlyAPI:
         https://bravado.readthedocs.io/en/stable/quickstart.html#usage
     """
 
-    def __init__(self, accountId, projectId, token=False, swaggerURL='https://api.optimizely.com/v2/swagger.json'):
+    def __init__(self, accountId, projectId, token=False, download_swagger=True, swaggerURL='https://api.optimizely.com/v2/swagger.json'):
 
         """
         Please refer to help(OptlyAPI) for more information
@@ -40,22 +40,23 @@ class OptlyAPI:
         self.accountId = accountId
         self.projectId = projectId
         self.swaggerURL = swaggerURL
-        self.config = {'use_models': False, 'validate_responses': False, 'validate_requests':False}
+        if download_swagger:
+            self.config = {'use_models': False, 'validate_responses': False, 'validate_requests':False}
 
-        if token:
-            self.token = 'Bearer {}'.format(token)
-            # applying authentication to all future requests for REST API
-            self.http_client = RequestsClient()
-            self.http_client.set_api_key(
-                'api.optimizely.com', self.token,
-                param_name='Authorization', param_in='header'
-                        )
-            self.client = SwaggerClient.from_url(swaggerURL, http_client=self.http_client, config=self.config) # creating bravado client from swagger.json
-        else:
-            self.client = SwaggerClient.from_url(swaggerURL, config=self.config) # creating bravado client from swagger.json if no token provided
+            if token:
+                self.token = 'Bearer {}'.format(token)
+                # applying authentication to all future requests for REST API
+                self.http_client = RequestsClient()
+                self.http_client.set_api_key(
+                    'api.optimizely.com', self.token,
+                    param_name='Authorization', param_in='header'
+                            )
+                self.client = SwaggerClient.from_url(swaggerURL, http_client=self.http_client, config=self.config) # creating bravado client from swagger.json
+            else:
+                self.client = SwaggerClient.from_url(swaggerURL, config=self.config) # creating bravado client from swagger.json if no token provided
 
 
-    def read_csv(self, file_path, delimiter=','):
+    def read_data(self, data=None, file_path=None, type='csv/tsv', delimiter=','):
         """
         The read_csv method wraps the pandas read_csv method and makes it possible to read in csv/tsv. This method returns an instance
         of the Response class.
@@ -69,7 +70,13 @@ class OptlyAPI:
         delimiter: str
             The delimiter between data columns, denotes CSV (,) or TSV (\t)
         """
-        df = read_csv(file_path, delimiter=delimiter) # read in the csv/tsv data 
+        if type == 'csv/tsv':
+            df = read_csv(file_path, delimiter=delimiter) # read in the csv/tsv data 
+        elif type == 'df':
+            df = data
+        else:
+            df = None
+            print('An invalid type was given for this method, the following are the supported values for the type param: csv/tsv, df')
         response = Response(df, self.accountId)
 
         return response
